@@ -1,5 +1,5 @@
 package Mira::Plugin::Jdate;
-$Mira::Plugin::Jdate::VERSION = '00.07.24';
+$Mira::Plugin::Jdate::VERSION = '00.07.25';
 
 use strict;
 use warnings;
@@ -103,7 +103,7 @@ sub plug {
         my $list_test;
         if ( $config->{lists} ) {
             foreach my $list ( @{ $config->{lists} } ) {
-                $list_test = 'list' if $list eq 'jdate';
+                $list_test = 'list' if $list =~ /^jdate$/i;
             }
         }
 
